Create a Card Vector
card.RdConstructs a custom S3 rcrd object of class "card", with validated rank and suit fields.
Used as the foundation for representing cards in the Blackjack game package.
card.RdConstructs a custom S3 rcrd object of class "card", with validated rank and suit fields.
Used as the foundation for representing cards in the Blackjack game package.